"use server"

import prisma from "@/lib/prisma"
import { commissionTypeSchema } from "@/schemas/commissionType"

export async function createCommissionOption(data: { name: string }) {
  return await prisma.commissionOption.create({
    data: {
      name: data.name,
      description: "",
    },
  })
}

export async function createCommissionExtra(data: { name: string }) {
  return await prisma.commissionExtra.create({
    data: {
      name: data.name,
      description: "",
    },
  })
}

export async function createCommissionType(formData: commissionTypeSchema) {
  const parsed = commissionTypeSchema.safeParse(formData)

  if (!parsed.success) {
    console.error("Validation failed", parsed.error)
    throw new Error("Invalid input")
  }

  const data = parsed.data

  const created = await prisma.commissionType.create({
    data: {
      name: data.name,
      description: data.description,
      options: {
        create: data.options?.map((opt, index) => ({
          option: { connect: { id: opt.optionId } },
          price: opt.price,
          pricePercent: opt.pricePercent,
          priceRange: opt.priceRange,
          sortIndex: index,
        })) || [],
      },
      extras: {
        create: data.extras?.map((ext, index) => ({
          extra: { connect: { id: ext.extraId } },
          price: ext.price,
          pricePercent: ext.pricePercent,
          priceRange: ext.priceRange,
          sortIndex: index,
        })) || [],
      },
    },
  })

  return created
}