import EditTypeForm from "@/components/items/commissions/types/EditTypeForm";
import prisma from "@/lib/prisma";

export default async function CommissionTypesEditPage({ params }: { params: { id: string } }) {
  const { id } = await params;
  const commissionType = await prisma.commissionType.findUnique({
    where: {
      id,
    },
    include: {
      options: { include: { option: true }, orderBy: { sortIndex: "asc" } },
      extras: { include: { extra: true }, orderBy: { sortIndex: "asc" } },
    },
  })
  const options = await prisma.commissionOption.findMany({
    orderBy: [{ sortIndex: "asc" }, { name: "asc" }],
  });
  const extras = await prisma.commissionExtra.findMany({
    orderBy: [{ sortIndex: "asc" }, { name: "asc" }],
  })

  if (!commissionType) {
    return <div>Type not found</div>
  }

  return (
    <div>
      <div className="flex gap-4 justify-between pb-8">
        <h1 className="text-2xl font-bold mb-4">New Commission Type</h1>
      </div>
      <EditTypeForm type={commissionType} allOptions={options} allExtras={extras} />
    </div>
  );
}