"use client"

import { Button } from "@/components/ui/button"
import {
  Command,
  CommandEmpty,
  CommandGroup,
  CommandInput,
  CommandItem,
} from "@/components/ui/command"
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover"
import { cn } from "@/lib/utils"
import { Check, ChevronsUpDown, PlusCircle } from "lucide-react"
import { useState } from "react"

type Option = {
  label: string
  value: string
}

type Props = {
  options: Option[]
  selected: string | undefined
  onSelect: (value: string) => void
  onCreateNew: (name: string) => void | Promise<void>
  placeholder?: string
  disabled?: boolean
}

export function ComboboxCreateable({
  options,
  selected,
  onSelect,
  onCreateNew,
  placeholder = "Select or create…",
  disabled = false,
}: Props) {
  const [open, setOpen] = useState(false)
  const [input, setInput] = useState("")

  const selectedOption = options.find((o) => o.value === selected)

  const filteredOptions = input
    ? options.filter((opt) =>
      opt.label.toLowerCase().includes(input.toLowerCase())
    )
    : options

  const showCreate = input && !options.some((o) => o.label.toLowerCase() === input.toLowerCase())

  return (
    <Popover open={open} onOpenChange={setOpen}>
      <PopoverTrigger asChild>
        <Button
          variant="outline"
          role="combobox"
          className="w-full justify-between"
          disabled={disabled}
        >
          {selectedOption?.label || placeholder}
          <ChevronsUpDown className="ml-2 h-4 w-4 opacity-50" />
        </Button>
      </PopoverTrigger>
      <PopoverContent className="w-[300px] p-0">
        <Command>
          <CommandInput
            placeholder={placeholder}
            value={input}
            onValueChange={setInput}
          />
          <CommandEmpty>No results</CommandEmpty>
          <CommandGroup>
            {filteredOptions.map((opt) => (
              <CommandItem
                key={opt.value}
                onSelect={() => {
                  onSelect(opt.value)
                  setOpen(false)
                }}
              >
                <Check
                  className={cn(
                    "mr-2 h-4 w-4",
                    selected === opt.value ? "opacity-100" : "opacity-0"
                  )}
                />
                {opt.label}
              </CommandItem>
            ))}
            {showCreate && (
              <CommandItem
                onSelect={async () => {
                  await onCreateNew(input)
                  setOpen(false)
                }}
                className="text-primary"
              >
                <PlusCircle className="mr-2 h-4 w-4" />
                Create “{input}”
              </CommandItem>
            )}
          </CommandGroup>
        </Command>
      </PopoverContent>
    </Popover>
  )
}
